<?php

namespace App\Http\Controllers\Api;

use App\Models\Account;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Http\Resources\CaisseResource;
use App\Http\Resources\CaisseCollection;

class AccountCaissesController extends Controller
{
    public function index(Request $request, Account $account): CaisseCollection
    {
        $this->authorize('view', $account);

        $search = $request->get('search', '');

        $caisses = $account
            ->caisses()
            ->search($search)
            ->latest()
            ->paginate();

        return new CaisseCollection($caisses);
    }

    public function store(Request $request, Account $account): CaisseResource
    {
        $this->authorize('create', Caisse::class);

        $validated = $request->validate([
            'code_caisse' => ['required', 'max:255', 'string'],
            'code_caisse_imp' => ['required', 'max:255', 'string'],
            'designation' => ['required', 'max:255', 'string'],
            'date_caisse' => ['required', 'date'],
            'id_tour' => ['nullable', 'exists:tours,id'],
            'alger_id' => ['nullable', 'exists:cashes,id'],
        ]);

        $caisse = $account->caisses()->create($validated);

        return new CaisseResource($caisse);
    }
}
