<?php

namespace App\Http\Controllers\Api;

use App\Models\Account;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Http\Resources\CasheResource;
use App\Http\Resources\CasheCollection;

class AccountCashesController extends Controller
{
    public function index(Request $request, Account $account): CasheCollection
    {
        $this->authorize('view', $account);

        $search = $request->get('search', '');

        $cashes = $account
            ->caches()
            ->search($search)
            ->latest()
            ->paginate();

        return new CasheCollection($cashes);
    }

    public function store(Request $request, Account $account): CasheResource
    {
        $this->authorize('create', Cashe::class);

        $validated = $request->validate([
            'code' => ['required', 'max:255', 'string'],
            'amount' => ['required', 'numeric'],
            'date' => ['required', 'date'],
            'in' => ['required', 'boolean'],
            'description' => ['required', 'max:255', 'string'],
            'tour_id' => ['nullable', 'exists:tours,id'],
            'user_id' => ['required', 'exists:users,id'],
            'done' => ['nullable', 'boolean'],
        ]);

        $cashe = $account->caches()->create($validated);

        return new CasheResource($cashe);
    }
}
