<?php

namespace App\Http\Controllers\Api;

use App\Models\Account;
use Illuminate\Http\Request;
use Illuminate\Http\Response;
use App\Http\Controllers\Controller;
use App\Http\Resources\AccountResource;
use App\Http\Resources\AccountCollection;
use App\Http\Requests\AccountStoreRequest;
use App\Http\Requests\AccountUpdateRequest;
use App\Models\Caisse;
use Illuminate\Support\Facades\DB;

class AccountController extends Controller
{
    public function getaccounts(): AccountCollection
    {
        $this->authorize('view-any', Account::class);
        $accounts = Account::all();
        return new AccountCollection($accounts);
    }
    public function getaccountstatement($id)
    {
        $this->authorize('view-any', Account::class);
        $accounts = Account::with(['achats', 'orders', 'caisses'])->find($id);
        return $accounts;
    }
    public function getstatement($id)
    {
        $result = DB::select('
            (SELECT
                "SOLD" AS type,
                "####/####" AS code,
                "####/####" AS id_select,
                id AS selectedaccount,
                "2016-01-01 00:00:00" AS mdate,
                sold AS money,
                "Sold start ..." AS note
            FROM
                accounts
            WHERE
                accounts.id = ?)
            UNION ALL
            (SELECT
                "PAYMENT" AS type,
                caisses.code_caisse AS code,
                caisses.id AS id_select,
                caisses.account_id AS selectedaccount,
                caisses.date_caisse AS mdate,
                -(caisses.mont) AS money,
                designation AS note
            FROM
                caisses
            WHERE
                caisses.account_id = ?)
            UNION ALL
            (SELECT
                "COMMANDE" AS type,
                orders.code_order as code,
                orders.account_id AS selectedaccount,
                orders.id AS id_select,
                orders.dt_order as mdate,
                SUM(sells.qte * sells.price) as money,
                "commande PAR CLIENT" AS note
            FROM
                orders
            JOIN
                sells ON orders.id = sells.order_id
            WHERE
                orders.account_id = ?
            GROUP BY
                orders.code_order, orders.account_id, orders.id, orders.dt_order)
            UNION ALL
            (SELECT
                "RETOUR" AS type,
                achats.code_achat as code,
                achats.account_id AS selectedaccount,
                achats.id AS id_select,
                achats.dt_achat as mdate,
                (-1 * SUM(buys.qte * buys.price)) as money,
                "Retour PAR CLIENT" AS note
            FROM
                achats
            JOIN
                buys ON achats.id = buys.achat_id
            WHERE
                achats.account_id = ?
            GROUP BY
                achats.code_achat, achats.account_id, achats.id, achats.dt_achat)
            ORDER BY mdate', [$id, $id, $id, $id]);
        return $result;
    }
    public function index(Request $request): AccountCollection
    {
        $this->authorize('view-any', Account::class);

        $search = $request->get('search', '');

        $accounts = Account::search($search)
            ->latest()
            ->get();

        return new AccountCollection($accounts);
    }

    public function store(AccountStoreRequest $request): AccountResource
    {
        $this->authorize('create', Account::class);

        $validated = $request->validated();

        $account = Account::create($validated);

        return new AccountResource($account);
    }

    public function show(Request $request, Account $account): AccountResource
    {
        $this->authorize('view', $account);

        return new AccountResource($account);
    }

    public function update(
        AccountUpdateRequest $request,
        Account $account
    ): AccountResource {
        $this->authorize('update', $account);

        $validated = $request->validated();

        $account->update($validated);

        return new AccountResource($account);
    }

    public function destroy(Request $request, Account $account): Response
    {
        $this->authorize('delete', $account);

        $account->delete();

        return response()->noContent();
    }
}
