<?php

namespace App\Http\Controllers\Api;

use App\Models\Account;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Http\Resources\PurchaseResource;
use App\Http\Resources\PurchaseCollection;

class AccountPurchasesController extends Controller
{
    public function index(
        Request $request,
        Account $account
    ): PurchaseCollection {
        $this->authorize('view', $account);

        $search = $request->get('search', '');

        $purchases = $account
            ->purchases()
            ->search($search)
            ->latest()
            ->paginate();

        return new PurchaseCollection($purchases);
    }

    public function store(Request $request, Account $account): PurchaseResource
    {
        $this->authorize('create', Purchase::class);

        $validated = $request->validate([
            'ref' => ['nullable', 'max:255', 'string'],
            'code' => ['required', 'max:255', 'string'],
            'date' => ['required', 'date'],
            'remise' => ['nullable', 'numeric'],
            'description' => ['nullable', 'max:255', 'string'],
            'user_id' => ['nullable', 'exists:users,id'],
            'done' => ['nullable', 'boolean'],
        ]);

        $purchase = $account->purchases()->create($validated);

        return new PurchaseResource($purchase);
    }
}
