<?php

namespace App\Http\Controllers\Api;

use App\Models\Account;
use Illuminate\Http\Request;
use App\Http\Resources\SaleResource;
use App\Http\Controllers\Controller;
use App\Http\Resources\SaleCollection;

class AccountSalesController extends Controller
{
    public function index(Request $request, Account $account): SaleCollection
    {
        $this->authorize('view', $account);

        $search = $request->get('search', '');

        $sales = $account
            ->sales()
            ->search($search)
            ->latest()
            ->paginate();

        return new SaleCollection($sales);
    }

    public function store(Request $request, Account $account): SaleResource
    {
        $this->authorize('create', Sale::class);

        $validated = $request->validate([
            'ref' => ['nullable', 'max:255', 'string'],
            'code' => ['required', 'max:255', 'string'],
            'date' => ['required', 'date'],
            'remise' => ['nullable', 'numeric'],
            'description' => ['nullable', 'max:255', 'string'],
            'user_id' => ['nullable', 'exists:users,id'],
            'done' => ['nullable', 'boolean'],
        ]);

        $sale = $account->sales()->create($validated);

        return new SaleResource($sale);
    }
}
