<?php

namespace App\Http\Controllers\Api;

use App\Models\Cashe;
use Illuminate\Http\Request;
use Illuminate\Http\Response;
use App\Http\Resources\CasheResource;
use App\Http\Controllers\Controller;
use App\Http\Resources\CasheCollection;
use App\Http\Requests\CasheStoreRequest;
use App\Http\Requests\CasheUpdateRequest;
use Illuminate\Support\Facades\Auth;

class CasheController extends Controller
{
    public function getcashes(Request $request): CasheCollection
    {
        $this->authorize('view-any', Cashe::class);

        $search = $request->get('search', '');
        $params = $request->get('params', '');

        $cashes = Cashe::search($search);
        $cashes = $cashes->latest()->paginate();

        return new CasheCollection($cashes);
    }
    public function index(Request $request): CasheCollection
    {
        $this->authorize('view-any', Cashe::class);

        $search = $request->get('search', '');

        $cashes = Cashe::search($search)
            ->latest()
            ->paginate();

        return new CasheCollection($cashes);
    }

    public function store(CasheStoreRequest $request): CasheResource
    {
        $this->authorize('create', Cashe::class);
        // $request->merge(['code' => $code, 'date' => now(), 'user_id' => Auth::user()->id]);
        $validated = $request->validated();

        $cashe = Cashe::create($validated);

        return new CasheResource($cashe);
    }

    public function show(Request $request, Cashe $cashe): CasheResource
    {
        $this->authorize('view', $cashe);

        return new CasheResource($cashe);
    }

    public function update(CasheUpdateRequest $request, Cashe $cashe): CasheResource
    {
        $this->authorize('update', $cashe);

        $validated = $request->validated();

        $cashe->update($validated);

        return new CasheResource($cashe);
    }

    public function destroy(Request $request, Cashe $cashe): Response
    {
        $this->authorize('delete', $cashe);

        $cashe->delete();

        return response()->noContent();
    }
    public function getcashecode()
    {
        $alpha = 0;
        $gamma = 0;
        $alpha1 = 0;
        $gamma1 = 0;
        $order = Cashe::orderBy('updated_at', 'desc')->withTrashed()->first();
        if ($order && $order->code) {
            $code = Cashe::orderBy('updated_at', 'desc')->withTrashed()->first()->code;
            $alpha = substr($code, 0, -8);
            $gamma = substr($code, -4);
            if ($alpha != date("Y")) {
                $new_code = date("Y") . '/CT/0001';
            } else {

                $alpha1 = date("Y");
                $gamma1 = $gamma + 1;
                $new_code = $alpha1 . '/CT/' . sprintf("%04s", $gamma1);
            }
        } else {
            $new_code = date("Y") . '/CT/0001';
        };
        return $new_code;
    }
}
