<?php

namespace App\Http\Controllers\Api;

use App\Models\Product;
use Illuminate\Http\Request;
use App\Http\Resources\BuyResource;
use App\Http\Controllers\Controller;
use App\Http\Resources\BuyCollection;

class ProductBuysController extends Controller
{
    public function index(Request $request, Product $product): BuyCollection
    {
        $this->authorize('view', $product);

        $search = $request->get('search', '');

        $buys = $product
            ->buys()
            ->search($search)
            ->latest()
            ->paginate();

        return new BuyCollection($buys);
    }

    public function store(Request $request, Product $product): BuyResource
    {
        $this->authorize('create', Buy::class);

        $validated = $request->validate([
            'qty' => ['required', 'numeric'],
            'price' => ['required', 'numeric'],
            'achat_id' => ['required', 'exists:achats,id'],
        ]);

        $buy = $product->buys()->create($validated);

        return new BuyResource($buy);
    }
}
