<?php

namespace App\Http\Controllers\Api;

use App\Models\Product;
use Illuminate\Http\Request;
use Illuminate\Http\Response;
use App\Http\Controllers\Controller;
use App\Http\Resources\ProductResource;
use App\Http\Resources\ProductCollection;
use App\Http\Requests\ProductStoreRequest;
use App\Http\Requests\ProductUpdateRequest;
use App\Models\Account;
use App\Models\Buy;
use App\Models\Sell;
use Illuminate\Support\Facades\DB;

class ProductController extends Controller
{
    public function getproducts(): ProductCollection
    {
        $this->authorize('view-any', Product::class);


        $products = Product::all();

        return new ProductCollection($products);
    }

    public function getstocks()
    {
        $this->authorize('view-any', Product::class);
        $account_id = 531; // Replace <account_id> with the actual account ID

        $results = DB::select(
            "SELECT
        products.id,
        products.code_product,
        products.nm_product,
        products.fr_nm_product,
        series.nm_serie,
        series.fr_nm_serie,
        COALESCE(SUM(sells_qte), 0) AS qty_sold,
        COALESCE(SUM(buys_qte), 0) AS qty_bought
    FROM
        products
    JOIN
        series ON products.serie_id = series.id
    LEFT JOIN (
        SELECT
            product_id,
            SUM(qte) AS sells_qte
        FROM
            sells
        LEFT JOIN
            orders ON sells.order_id = orders.id
        WHERE
            orders.account_id = ?
        GROUP BY
            product_id
    ) AS sells_agg ON products.id = sells_agg.product_id
    LEFT JOIN (
        SELECT
            product_id,
            SUM(qte) AS buys_qte
        FROM
            buys
        LEFT JOIN
            achats ON buys.achat_id = achats.id
        WHERE
            achats.account_id = ?
        GROUP BY
            product_id
    ) AS buys_agg ON products.id = buys_agg.product_id

    GROUP BY
        products.id",
            [$account_id, $account_id]
        );


        // Product::with('serie')
        //     ->select(
        //         'products.id',
        //         'products.code_product',
        //         'products.nm_product',
        //         'products.fr_nm_product',
        //         'series.nm_serie',
        //         'series.fr_nm_serie',
        //         DB::raw('SUM(sells.qte) as qty_sold'),
        //         DB::raw('0 as qty_bought')
        //     )
        //     ->join('series', 'products.serie_id', '=', 'series.id')
        //     ->join('sells', 'products.id', '=', 'sells.product_id')
        //     ->join('orders', 'sells.order_id', '=', 'orders.id')
        //     ->where('orders.account_id', 531)
        //     ->groupBy('products.id', 'products.code_product', 'products.nm_product')
        //     ->get();


        // $productQuantities = Product::leftJoin('sells', 'products.id', '=', 'sells.product_id')
        //     ->leftJoin('series', 'products.serie_id', '=', 'series.id')
        //     ->leftJoin('buys', 'products.id', '=', 'buys.product_id')
        //     ->leftJoin('orders', 'sells.order_id', '=', 'orders.id')
        //     ->leftJoin('achats', 'buys.achat_id', '=', 'achats.id')
        //     ->select(
        //         'products.id',
        //         'products.code_product',
        //         'products.nm_product',
        //         'products.fr_nm_product',
        //         'series.nm_serie',
        //         'series.fr_nm_serie',
        //         DB::raw('SUM(CASE WHEN orders.account_id = 531 THEN sells.qte ELSE 0 END) AS qty_sold'),
        //         DB::raw('SUM(CASE WHEN achats.account_id = 531 THEN buys.qte ELSE 0 END) AS qty_bought')
        //     )
        //     ->groupBy('products.id', 'products.nm_product', 'products.fr_nm_product')
        //     ->get();

        return response()->json($results);
        // return new ProductCollection($products);
    }
    public function index(Request $request): ProductCollection
    {
        $this->authorize('view-any', Product::class);

        $search = $request->get('search', '');

        $products = Product::search($search)
            ->latest()
            ->get();

        return new ProductCollection($products);
    }

    public function store(ProductStoreRequest $request): ProductResource
    {
        $this->authorize('create', Product::class);

        $validated = $request->validated();

        $product = Product::create($validated);

        return new ProductResource($product);
    }

    public function show(Request $request, Product $product): ProductResource
    {
        $this->authorize('view', $product);

        return new ProductResource($product);
    }

    public function update(
        ProductUpdateRequest $request,
        Product $product
    ): ProductResource {
        $this->authorize('update', $product);

        $validated = $request->validated();

        $product->update($validated);

        return new ProductResource($product);
    }

    public function destroy(Request $request, Product $product): Response
    {
        $this->authorize('delete', $product);
        $product->delete();
        return response()->noContent();
    }
}
