<?php

namespace App\Http\Controllers\Api;

use App\Models\Product;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Http\Resources\PurchaseitemResource;
use App\Http\Resources\PurchaseitemCollection;

class ProductPurchaseitemsController extends Controller
{
    public function index(
        Request $request,
        Product $product
    ): PurchaseitemCollection {
        $this->authorize('view', $product);

        $search = $request->get('search', '');

        $purchaseitems = $product
            ->purchaseitems()
            ->search($search)
            ->latest()
            ->paginate();

        return new PurchaseitemCollection($purchaseitems);
    }

    public function store(
        Request $request,
        Product $product
    ): PurchaseitemResource {
        $this->authorize('create', Purchaseitem::class);

        $validated = $request->validate([
            'qty' => ['required', 'numeric'],
            'price' => ['required', 'numeric'],
            'description' => ['nullable', 'max:255', 'string'],
        ]);

        $purchaseitem = $product->purchaseitems()->create($validated);

        return new PurchaseitemResource($purchaseitem);
    }
}
