<?php

namespace App\Http\Controllers\Api;

use App\Models\Product;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Http\Resources\SaleitemResource;
use App\Http\Resources\SaleitemCollection;

class ProductSaleitemsController extends Controller
{
    public function index(
        Request $request,
        Product $product
    ): SaleitemCollection {
        $this->authorize('view', $product);

        $search = $request->get('search', '');

        $saleitems = $product
            ->saleitems()
            ->search($search)
            ->latest()
            ->paginate();

        return new SaleitemCollection($saleitems);
    }

    public function store(Request $request, Product $product): SaleitemResource
    {
        $this->authorize('create', Saleitem::class);

        $validated = $request->validate([
            'qty' => ['required', 'numeric'],
            'price' => ['required', 'numeric'],
            'description' => ['nullable', 'max:255', 'string'],
        ]);

        $saleitem = $product->saleitems()->create($validated);

        return new SaleitemResource($saleitem);
    }
}
