<?php

namespace App\Http\Controllers\Api;

use App\Models\Product;
use Illuminate\Http\Request;
use App\Http\Resources\SellResource;
use App\Http\Controllers\Controller;
use App\Http\Resources\SellCollection;

class ProductSellsController extends Controller
{
    public function index(Request $request, Product $product): SellCollection
    {
        $this->authorize('view', $product);

        $search = $request->get('search', '');

        $sells = $product
            ->sells()
            ->search($search)
            ->latest()
            ->paginate();

        return new SellCollection($sells);
    }

    public function store(Request $request, Product $product): SellResource
    {
        $this->authorize('create', Sell::class);

        $validated = $request->validate([
            'order_id' => ['required', 'exists:orders,id'],
            'qte' => ['required', 'numeric'],
            'price' => ['required', 'numeric'],
        ]);

        $sell = $product->sells()->create($validated);

        return new SellResource($sell);
    }
}
