<?php

namespace App\Http\Controllers\Api;

use App\Models\Purchase;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Http\Resources\AchatResource;
use App\Http\Resources\AchatCollection;

class PurchaseAchatsController extends Controller
{
    public function index(Request $request, Purchase $purchase): AchatCollection
    {
        $this->authorize('view', $purchase);

        $search = $request->get('search', '');

        $achats = $purchase
            ->achats()
            ->search($search)
            ->latest()
            ->paginate();

        return new AchatCollection($achats);
    }

    public function store(Request $request, Purchase $purchase): AchatResource
    {
        $this->authorize('create', Achat::class);

        $validated = $request->validate([
            'code_achat' => ['required', 'max:255', 'string'],
            'code_imp' => ['nullable', 'max:255', 'string'],
            'dt_achat' => ['required', 'date'],
            'tot' => ['nullable', 'numeric'],
            'rem_achat' => ['nullable', 'numeric'],
            'nb_colis' => ['nullable', 'numeric'],
            'phases' => ['nullable', 'numeric'],
            'status_achat' => ['nullable', 'max:255', 'string'],
            'user_achat' => ['nullable', 'exists:users,id'],
            'preparation_par' => ['nullable', 'max:255', 'string'],
            'enroute_par' => ['nullable', 'max:255', 'string'],
            'conf_user' => ['nullable', 'exists:users,id'],
            'conf_par' => ['nullable', 'max:255', 'string'],
            'dt_conf' => ['nullable', 'date'],
            'id_tour' => ['nullable', 'exists:tours,id'],
        ]);

        $achat = $purchase->achats()->create($validated);

        return new AchatResource($achat);
    }
}
