<?php

namespace App\Http\Controllers\Api;

use App\Models\Purchase;
use Illuminate\Http\Request;
use Illuminate\Http\Response;
use App\Http\Resources\PurchaseResource;
use App\Http\Controllers\Controller;
use App\Http\Resources\PurchaseCollection;
use App\Http\Requests\PurchaseStoreRequest;
use App\Http\Requests\PurchaseUpdateRequest;
use App\Models\Purchaseitem;
use Illuminate\Support\Facades\Auth;

class PurchaseController extends Controller
{
    public function getpurchases(Request $request): PurchaseCollection
    {
        $this->authorize('view-any', Purchase::class);

        $search = $request->get('search', '');
        $params = $request->get('params', '');

        $purchases = Purchase::search($search);
        $purchases = $purchases->latest()->paginate();

        return new PurchaseCollection($purchases);
    }
    public function index(Request $request): PurchaseCollection
    {
        $this->authorize('view-any', Purchase::class);

        $search = $request->get('search', '');

        $purchases = Purchase::search($search)
            ->latest()
            ->paginate();

        return new PurchaseCollection($purchases);
    }

    public function store(PurchaseStoreRequest $request): PurchaseResource
    {
        $this->authorize('create', Purchase::class);
        // $request->merge(['code' => $code, 'date' => now(), 'user_id' => Auth::user()->id]);
        $validated = $request->validated();

        $purchase = Purchase::create($validated);

        $purchase_id = $purchase->id;

        for ($i = 0; $i < count($request->purchaseitems); $i++) {
            $purchaseitem = new Purchaseitem();
            $purchaseitem->fill([
                'purchase_id' => $purchase_id,
                'product_id' => $request->purchaseitems[$i]['product_id'],
                'qty' => $request->purchaseitems[$i]['qty'],
                'price' => $request->purchaseitems[$i]['price'],
                'description' => $request->purchaseitems[$i]['description'],
            ])->save();
        }
        return new PurchaseResource($purchase);
    }

    public function show(Request $request, Purchase $purchase): PurchaseResource
    {
        $this->authorize('view', $purchase);

        return new PurchaseResource($purchase);
    }

    public function update(PurchaseUpdateRequest $request, Purchase $purchase): PurchaseResource
    {
        $this->authorize('update', $purchase);

        $validated = $request->validated();

        $purchase->update($validated);
        $purchase_id = $purchase->id;

        Purchaseitem::where('purchase_id', $purchase_id)->whereNotIn('id', array_column($request->purchaseitems, 'id'))->delete();
        for ($i = 0; $i < count($request->purchaseitems); $i++) {

            if ($request->purchaseitems[$i]['id']) {
                $purchaseitem = Purchaseitem::where(['id' => $request->purchaseitems[$i]['id']])->first();
                $purchaseitem->purchase_id = $purchase_id;
                $purchaseitem->product_id = $request->purchaseitems[$i]['product_id'];
                $purchaseitem->qty = $request->purchaseitems[$i]['qty'];
                $purchaseitem->price = $request->purchaseitems[$i]['price'];
                $purchaseitem->description = $request->purchaseitems[$i]['description'];
                $purchaseitem->save();
            } else {
                $purchaseitem = new Purchaseitem();
                $purchaseitem->fill([
                    'purchase_id' => $purchase_id,
                    'product_id' => $request->purchaseitems[$i]['product_id'],
                    'qty' => $request->purchaseitems[$i]['qty'],
                    'price' => $request->purchaseitems[$i]['price'],
                    'description' => $request->purchaseitems[$i]['description'],
                ])->save();
            }
        }

        return new PurchaseResource($purchase);
    }

    public function destroy(Request $request, Purchase $purchase): Response
    {
        $this->authorize('delete', $purchase);

        $purchase->delete();

        return response()->noContent();
    }
    public function getpurchasecode()
    {
        $alpha = 0;
        $gamma = 0;
        $alpha1 = 0;
        $gamma1 = 0;
        $order = Purchase::orderBy('updated_at', 'desc')->withTrashed()->first();
        if ($order && $order->code) {
            $code = Purchase::orderBy('updated_at', 'desc')->withTrashed()->first()->code;
            $alpha = substr($code, 0, -8);
            $gamma = substr($code, -4);
            if ($alpha != date("Y")) {
                $new_code = date("Y") . '/AT/0001';
            } else {

                $alpha1 = date("Y");
                $gamma1 = $gamma + 1;
                $new_code = $alpha1 . '/AT/' . sprintf("%04s", $gamma1);
            }
        } else {
            $new_code = date("Y") . '/AT/0001';
        };
        return $new_code;
    }
}
