<?php

namespace App\Http\Controllers\Api;

use App\Models\Sale;
use Illuminate\Http\Request;
use Illuminate\Http\Response;
use App\Http\Resources\SaleResource;
use App\Http\Controllers\Controller;
use App\Http\Resources\SaleCollection;
use App\Http\Requests\SaleStoreRequest;
use App\Http\Requests\SaleUpdateRequest;
use App\Models\Saleitem;
use Illuminate\Support\Facades\Auth;

class SaleController extends Controller
{
    public function getsales(Request $request): SaleCollection
    {
        $this->authorize('view-any', Sale::class);

        $search = $request->get('search', '');
        $params = $request->get('params', '');

        $sales = Sale::search($search);
        $sales = $sales->latest()->paginate();

        return new SaleCollection($sales);
    }
    public function index(Request $request): SaleCollection
    {
        $this->authorize('view-any', Sale::class);

        $search = $request->get('search', '');

        $sales = Sale::search($search)
            ->latest()
            ->paginate();

        return new SaleCollection($sales);
    }

    public function store(SaleStoreRequest $request): SaleResource
    {
        $this->authorize('create', Sale::class);
        // $request->merge(['code' => $code, 'date' => now(), 'user_id' => Auth::user()->id]);
        $validated = $request->validated();

        $sale = Sale::create($validated);

        $sale_id = $sale->id;

        for ($i = 0; $i < count($request->saleitems); $i++) {
            $saleitem = new Saleitem();
            $saleitem->fill([
                'sale_id' => $sale_id,
                'product_id' => $request->saleitems[$i]['product_id'],
                'qty' => $request->saleitems[$i]['qty'],
                'price' => $request->saleitems[$i]['price'],
                'description' => $request->saleitems[$i]['description'],
            ])->save();
        }
        return new SaleResource($sale);
    }

    public function show(Request $request, Sale $sale): SaleResource
    {
        $this->authorize('view', $sale);

        return new SaleResource($sale);
    }

    public function update(SaleUpdateRequest $request, Sale $sale): SaleResource
    {
        $this->authorize('update', $sale);

        $validated = $request->validated();

        $sale->update($validated);
        $sale_id = $sale->id;

        Saleitem::where('sale_id', $sale_id)->whereNotIn('id', array_column($request->saleitems, 'id'))->delete();
        for ($i = 0; $i < count($request->saleitems); $i++) {

            if ($request->saleitems[$i]['id']) {
                $saleitem = Saleitem::where(['id' => $request->saleitems[$i]['id']])->first();
                $saleitem->sale_id = $sale_id;
                $saleitem->product_id = $request->saleitems[$i]['product_id'];
                $saleitem->qty = $request->saleitems[$i]['qty'];
                $saleitem->price = $request->saleitems[$i]['price'];
                $saleitem->description = $request->saleitems[$i]['description'];
                $saleitem->save();
            } else {
                $saleitem = new Saleitem();
                $saleitem->fill([
                    'sale_id' => $sale_id,
                    'product_id' => $request->saleitems[$i]['product_id'],
                    'qty' => $request->saleitems[$i]['qty'],
                    'price' => $request->saleitems[$i]['price'],
                    'description' => $request->saleitems[$i]['description'],
                ])->save();
            }
        }

        return new SaleResource($sale);
    }

    public function destroy(Request $request, Sale $sale): Response
    {
        $this->authorize('delete', $sale);

        $sale->delete();

        return response()->noContent();
    }
    public function getsalecode()
    {
        $alpha = 0;
        $gamma = 0;
        $alpha1 = 0;
        $gamma1 = 0;
        $order = Sale::orderBy('updated_at', 'desc')->withTrashed()->first();
        if ($order && $order->code) {
            $code = Sale::orderBy('updated_at', 'desc')->withTrashed()->first()->code;
            $alpha = substr($code, 0, -8);
            $gamma = substr($code, -4);
            if ($alpha != date("Y")) {
                $new_code = date("Y") . '/VT/0001';
            } else {

                $alpha1 = date("Y");
                $gamma1 = $gamma + 1;
                $new_code = $alpha1 . '/VT/' . sprintf("%04s", $gamma1);
            }
        } else {
            $new_code = date("Y") . '/VT/0001';
        };
        return $new_code;
    }
}
