<?php

namespace App\Http\Controllers\Api;

use App\Models\Sale;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Http\Resources\DeliveryResource;
use App\Http\Resources\DeliveryCollection;

class SaleDeliveriesController extends Controller
{
    public function index(Request $request, Sale $sale): DeliveryCollection
    {
        $this->authorize('view', $sale);

        $search = $request->get('search', '');

        $deliveries = $sale
            ->deliveries()
            ->search($search)
            ->latest()
            ->paginate();

        return new DeliveryCollection($deliveries);
    }

    public function store(Request $request, Sale $sale): DeliveryResource
    {
        $this->authorize('create', Delivery::class);

        $validated = $request->validate([
            'price' => ['nullable', 'numeric'],
            'from' => ['required', 'exists:places,id'],
            'to' => ['required', 'exists:places,id'],
            'date_ent' => ['nullable', 'date'],
            'date_sort' => ['nullable', 'date'],
            'conf_ent' => ['nullable', 'max:255', 'string'],
            'conf_sort' => ['nullable', 'max:255', 'string'],
            'user_ent' => ['nullable', 'exists:users,id'],
            'user_sort' => ['nullable', 'exists:users,id'],
            'description' => ['nullable', 'max:255', 'string'],
        ]);

        $delivery = $sale->deliveries()->create($validated);

        return new DeliveryResource($delivery);
    }
}
