<?php

namespace App\Http\Controllers\Api;

use App\Models\Sale;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Http\Resources\OrderResource;
use App\Http\Resources\OrderCollection;

class SaleOrdersController extends Controller
{
    public function index(Request $request, Sale $sale): OrderCollection
    {
        $this->authorize('view', $sale);

        $search = $request->get('search', '');

        $orders = $sale
            ->orders()
            ->search($search)
            ->latest()
            ->paginate();

        return new OrderCollection($orders);
    }

    public function store(Request $request, Sale $sale): OrderResource
    {
        $this->authorize('create', Order::class);

        $validated = $request->validate([
            'account_id' => ['required', 'exists:accounts,id'],
            'code_order' => ['required', 'max:255', 'string'],
            'dt_order' => ['required', 'date'],
            'tot' => ['nullable', 'numeric'],
            'rem_order' => ['nullable', 'numeric'],
            'nb_colis' => ['nullable', 'numeric'],
            'phase' => ['nullable', 'numeric'],
            'status_order' => ['required', 'max:255', 'string'],
            'user_order' => ['required', 'exists:users,id'],
            'preparation_par' => ['nullable', 'max:255', 'string'],
            'enroute_par' => ['nullable', 'max:255', 'string'],
            'conf_user' => ['nullable', 'exists:users,id'],
            'conf_par' => ['nullable', 'max:255', 'string'],
            'dt_conf' => ['nullable', 'date'],
            'id_tour' => ['nullable', 'exists:tours,id'],
        ]);

        $order = $sale->orders()->create($validated);

        return new OrderResource($order);
    }
}
