<?php

namespace App\Http\Controllers\Api;

use App\Models\Sale;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Http\Resources\SaleitemResource;
use App\Http\Resources\SaleitemCollection;

class SaleSaleitemsController extends Controller
{
    public function index(Request $request, Sale $sale): SaleitemCollection
    {
        $this->authorize('view', $sale);

        $search = $request->get('search', '');

        $saleitems = $sale
            ->saleitems()
            ->search($search)
            ->latest()
            ->paginate();

        return new SaleitemCollection($saleitems);
    }

    public function store(Request $request, Sale $sale): SaleitemResource
    {
        $this->authorize('create', Saleitem::class);

        $validated = $request->validate([
            'product_id' => ['required', 'exists:products,id'],
            'qty' => ['required', 'numeric'],
            'price' => ['required', 'numeric'],
            'description' => ['nullable', 'max:255', 'string'],
        ]);

        $saleitem = $sale->saleitems()->create($validated);

        return new SaleitemResource($saleitem);
    }
}
