<?php

namespace App\Http\Livewire;

use Livewire\Component;
use App\Models\Product;
use App\Models\Purchase;
use Illuminate\View\View;
use Livewire\WithPagination;
use App\Models\Purchaseitem;
use Illuminate\Foundation\Auth\Access\AuthorizesRequests;

class PurchasePuchaseitemsDetail extends Component
{
    use WithPagination;
    use AuthorizesRequests;

    public Purchase $purchase;
    public Purchaseitem $purchaseitem;
    public $productsForSelect = [];

    public $selected = [];
    public $editing = false;
    public $allSelected = false;
    public $showingModal = false;

    public $modalTitle = 'New Purchaseitem';

    protected $rules = [
        'puchaseitem.qty' => ['required', 'numeric'],
        'puchaseitem.price' => ['required', 'numeric'],
        'puchaseitem.product_id' => ['required', 'exists:products,id'],
        'puchaseitem.description' => ['nullable', 'max:255', 'string'],
    ];

    public function mount(Purchase $purchase): void
    {
        $this->purchase = $purchase;
        $this->productsForSelect = Product::pluck('nm_product', 'id');
        $this->resetPurchaseitemData();
    }

    public function resetPurchaseitemData(): void
    {
        $this->purchaseitem = new Purchaseitem();

        $this->puchaseitem->product_id = null;

        $this->dispatchBrowserEvent('refresh');
    }

    public function newPurchaseitem(): void
    {
        $this->editing = false;
        $this->modalTitle = trans('crud.purchase_puchaseitems.new_title');
        $this->resetPurchaseitemData();

        $this->showModal();
    }

    public function editPurchaseitem(Purchaseitem $purchaseitem): void
    {
        $this->editing = true;
        $this->modalTitle = trans('crud.purchase_puchaseitems.edit_title');
        $this->purchaseitem = $purchaseitem;

        $this->dispatchBrowserEvent('refresh');

        $this->showModal();
    }

    public function showModal(): void
    {
        $this->resetErrorBag();
        $this->showingModal = true;
    }

    public function hideModal(): void
    {
        $this->showingModal = false;
    }

    public function save(): void
    {
        $this->validate();

        if (!$this->purchaseitem->purchase_id) {
            $this->authorize('create', Purchaseitem::class);

            $this->purchaseitem->purchase_id = $this->purchase->id;
        } else {
            $this->authorize('update', $this->purchaseitem);
        }

        $this->purchaseitem->save();

        $this->hideModal();
    }

    public function destroySelected(): void
    {
        $this->authorize('delete-any', Purchaseitem::class);

        Purchaseitem::whereIn('id', $this->selected)->delete();

        $this->selected = [];
        $this->allSelected = false;

        $this->resetPurchaseitemData();
    }

    public function toggleFullSelection(): void
    {
        if (!$this->allSelected) {
            $this->selected = [];
            return;
        }

        foreach ($this->purchase->purchaseitems as $purchaseitem) {
            array_push($this->selected, $purchaseitem->id);
        }
    }

    public function render(): View
    {
        return view('livewire.purchase-puchaseitems-detail', [
            'purchaseitems' => $this->purchase->purchaseitems()->paginate(20),
        ]);
    }
}
