<?php

namespace App\Http\Livewire;

use App\Models\Sale;
use Livewire\Component;
use App\Models\Product;
use App\Models\Saleitem;
use Illuminate\View\View;
use Livewire\WithPagination;
use Illuminate\Foundation\Auth\Access\AuthorizesRequests;

class SaleSaleitemsDetail extends Component
{
    use WithPagination;
    use AuthorizesRequests;

    public Sale $sale;
    public Saleitem $saleitem;
    public $productsForSelect = [];

    public $selected = [];
    public $editing = false;
    public $allSelected = false;
    public $showingModal = false;

    public $modalTitle = 'New Saleitem';

    protected $rules = [
        'saleitem.product_id' => ['required', 'exists:products,id'],
        'saleitem.qty' => ['required', 'numeric'],
        'saleitem.price' => ['required', 'numeric'],
        'saleitem.description' => ['nullable', 'max:255', 'string'],
    ];

    public function mount(Sale $sale): void
    {
        $this->sale = $sale;
        $this->productsForSelect = Product::pluck('nm_product', 'id');
        $this->resetSaleitemData();
    }

    public function resetSaleitemData(): void
    {
        $this->saleitem = new Saleitem();

        $this->saleitem->product_id = null;

        $this->dispatchBrowserEvent('refresh');
    }

    public function newSaleitem(): void
    {
        $this->editing = false;
        $this->modalTitle = trans('crud.sale_saleitems.new_title');
        $this->resetSaleitemData();

        $this->showModal();
    }

    public function editSaleitem(Saleitem $saleitem): void
    {
        $this->editing = true;
        $this->modalTitle = trans('crud.sale_saleitems.edit_title');
        $this->saleitem = $saleitem;

        $this->dispatchBrowserEvent('refresh');

        $this->showModal();
    }

    public function showModal(): void
    {
        $this->resetErrorBag();
        $this->showingModal = true;
    }

    public function hideModal(): void
    {
        $this->showingModal = false;
    }

    public function save(): void
    {
        $this->validate();

        if (!$this->saleitem->sale_id) {
            $this->authorize('create', Saleitem::class);

            $this->saleitem->sale_id = $this->sale->id;
        } else {
            $this->authorize('update', $this->saleitem);
        }

        $this->saleitem->save();

        $this->hideModal();
    }

    public function destroySelected(): void
    {
        $this->authorize('delete-any', Saleitem::class);

        Saleitem::whereIn('id', $this->selected)->delete();

        $this->selected = [];
        $this->allSelected = false;

        $this->resetSaleitemData();
    }

    public function toggleFullSelection(): void
    {
        if (!$this->allSelected) {
            $this->selected = [];
            return;
        }

        foreach ($this->sale->saleitems as $saleitem) {
            array_push($this->selected, $saleitem->id);
        }
    }

    public function render(): View
    {
        return view('livewire.sale-saleitems-detail', [
            'saleitems' => $this->sale->saleitems()->paginate(20),
        ]);
    }
}
