<?php

namespace App\Models;

use App\Models\Scopes\Searchable;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Support\Facades\DB;

class Achat extends Model
{
    use HasFactory;
    use Searchable;
    use SoftDeletes;


    protected $with = ['buys', 'account'];

    protected $appends = ['total'];

    protected $fillable = [
        'id',
        'code_achat',
        'code_imp',
        'dt_achat',
        'tot',
        'rem_achat',
        'nb_colis',
        'phases',
        'status_achat',
        'user_achat',
        'preparation_par',
        'enroute_par',
        'conf_user',
        'conf_par',
        'dt_conf',
        'id_tour',
        'alger_id',
    ];

    protected $searchableFields = ['*'];

    protected $casts = [
        'dt_achat' => 'datetime',
        'dt_conf' => 'datetime',
    ];

    public function account()
    {
        return $this->belongsTo(Account::class);
    }

    public function conf_user()
    {
        return $this->belongsTo(User::class, 'conf_user');
    }

    public function user_achat()
    {
        return $this->belongsTo(User::class, 'user_achat');
    }

    public function id_tour()
    {
        return $this->belongsTo(Tour::class, 'id_tour');
    }

    public function alger_id()
    {
        return $this->belongsTo(Purchase::class, 'alger_id');
    }

    public function buys()
    {
        return $this->hasMany(Buy::class);
    }

    public function getTotalAttribute()
    {
        return $this->buys()->sum(DB::raw('qte * price'));
    }
}
