<?php

namespace App\Models;

use App\Models\Scopes\Searchable;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Database\Eloquent\Factories\HasFactory;

class Delivery extends Model
{
    use HasFactory;
    use Searchable;
    use SoftDeletes;

    protected $fillable = [
        'sale_id',
        'price',
        'from',
        'to',
        'date_ent',
        'date_sort',
        'conf_ent',
        'conf_sort',
        'user_ent',
        'user_sort',
        'description',
    ];

    protected $searchableFields = ['*'];

    protected $casts = [
        'date_ent' => 'datetime',
        'date_sort' => 'datetime',
    ];

    public function sale()
    {
        return $this->belongsTo(Sale::class);
    }

    public function from()
    {
        return $this->belongsTo(Place::class, 'from');
    }

    public function to()
    {
        return $this->belongsTo(Place::class, 'to');
    }

    public function user_ent()
    {
        return $this->belongsTo(User::class, 'user_ent');
    }

    public function user_sort()
    {
        return $this->belongsTo(User::class, 'user_sort');
    }
}
