<?php

namespace App\Models;

use App\Models\Scopes\Searchable;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Support\Facades\DB;

class Order extends Model
{
    use HasFactory;
    use Searchable;
    use SoftDeletes;

    protected $with = ['sells', 'account'];

    protected $appends = ['total'];

    protected $fillable = [
        'id',
        'account_id',
        'code_order',
        'dt_order',
        'tot',
        'rem_order',
        'nb_colis',
        'phase',
        'status_order',
        'user_order',
        'preparation_par',
        'enroute_par',
        'conf_user',
        'conf_par',
        'dt_conf',
        'id_tour',
        'alger_id',
    ];

    protected $searchableFields = ['*'];

    protected $casts = [
        'dt_order' => 'datetime',
        'dt_conf' => 'datetime',
    ];

    public function account()
    {
        return $this->belongsTo(Account::class);
    }

    public function user_order()
    {
        return $this->belongsTo(User::class, 'user_order');
    }

    public function conf_user()
    {
        return $this->belongsTo(User::class, 'conf_user');
    }

    public function id_tour()
    {
        return $this->belongsTo(Tour::class, 'id_tour');
    }

    public function alger_id()
    {
        return $this->belongsTo(Sale::class, 'alger_id');
    }

    public function sells()
    {
        return $this->hasMany(Sell::class);
    }

    public function getTotalAttribute()
    {
        return $this->sells()->sum(DB::raw('qte * price'));
    }
}
