<?php

namespace App\Models;

use App\Models\Scopes\Searchable;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Support\Facades\DB;

class Sale extends Model
{
    use HasFactory;
    use Searchable;
    use SoftDeletes;

    protected $appends = ['total'];
    protected $with = ['account', 'saleitems'];
    protected $fillable = [
        'id',
        'account_id',
        'ref',
        'code',
        'date',
        'remise',
        'description',
        'user_id',
        'done',
    ];

    protected $searchableFields = ['*'];

    protected $casts = [
        'date' => 'datetime',
        'done' => 'boolean',
    ];

    public function user()
    {
        return $this->belongsTo(User::class);
    }

    public function account()
    {
        return $this->belongsTo(Account::class);
    }

    public function saleitems()
    {
        return $this->hasMany(Saleitem::class);
    }

    public function getTotalAttribute()
    {
        return $this->saleitems()->sum(DB::raw('qty * price'));
    }
}
