<?php

namespace App\Models;

use Laravel\Sanctum\HasApiTokens;
use App\Models\Scopes\Searchable;
use Illuminate\Notifications\Notifiable;
use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Foundation\Auth\User as Authenticatable;

class User extends Authenticatable
{
    use Notifiable;
    use HasFactory;
    use Searchable;
    use HasApiTokens;

    protected $fillable = ['id', 'name', 'email', 'password'];

    protected $searchableFields = ['*'];

    protected $hidden = ['password', 'remember_token'];

    protected $casts = [
        'email_verified_at' => 'datetime',
    ];

    public function purchases()
    {
        return $this->hasMany(Purchase::class);
    }

    public function accounts()
    {
        return $this->hasMany(Account::class);
    }

    public function sales()
    {
        return $this->hasMany(Sale::class);
    }

    public function tours()
    {
        return $this->hasMany(Tour::class);
    }

    public function users_ent()
    {
        return $this->hasMany(Delivery::class, 'user_ent');
    }

    public function users_sort()
    {
        return $this->hasMany(Delivery::class, 'user_sort');
    }

    public function achats()
    {
        return $this->hasMany(Achat::class, 'conf_user');
    }

    public function achats2()
    {
        return $this->hasMany(Achat::class, 'user_achat');
    }

    public function cashes()
    {
        return $this->hasMany(Cashe::class);
    }

    public function orders()
    {
        return $this->hasMany(Order::class, 'user_order');
    }

    public function orders2()
    {
        return $this->hasMany(Order::class, 'conf_user');
    }

    public function isSuperAdmin(): bool
    {
        return in_array($this->email, config('auth.super_admins'));
    }
}
