<div>
    <div class="mb-4">
        @can('create', App\Models\Purchaseitem::class)
        <button class="btn btn-primary" wire:click="newPurchaseitem">
            <i class="icon ion-md-add"></i>
            @lang('crud.common.new')
        </button>
        @endcan @can('delete-any', App\Models\Purchaseitem::class)
        <button
            class="btn btn-danger"
             {{ empty($selected) ? 'disabled' : '' }} 
            onclick="confirm('Are you sure?') || event.stopImmediatePropagation()"
            wire:click="destroySelected"
        >
            <i class="icon ion-md-trash"></i>
            @lang('crud.common.delete_selected')
        </button>
        @endcan
    </div>

    <x-modal id="purchase-puchaseitems-modal" wire:model="showingModal">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title">{{ $modalTitle }}</h5>
                <button
                    type="button"
                    class="close"
                    data-dismiss="modal"
                    aria-label="Close"
                >
                    <span aria-hidden="true">&times;</span>
                </button>
            </div>

            <div class="modal-body">
                <div>
                    <x-inputs.group class="col-sm-12">
                        <x-inputs.number
                            name="puchaseitem.qty"
                            label="Qty"
                            wire:model="puchaseitem.qty"
                            max="255"
                            step="0.01"
                            placeholder="Qty"
                        ></x-inputs.number>
                    </x-inputs.group>

                    <x-inputs.group class="col-sm-12">
                        <x-inputs.number
                            name="puchaseitem.price"
                            label="Price"
                            wire:model="puchaseitem.price"
                            max="255"
                            step="0.01"
                            placeholder="Price"
                        ></x-inputs.number>
                    </x-inputs.group>

                    <x-inputs.group class="col-sm-12">
                        <x-inputs.select
                            name="puchaseitem.product_id"
                            label="Product"
                            wire:model="puchaseitem.product_id"
                        >
                            <option value="null" disabled>Please select the Product</option>
                            @foreach($productsForSelect as $value => $label)
                            <option value="{{ $value }}"  >{{ $label }}</option>
                            @endforeach
                        </x-inputs.select>
                    </x-inputs.group>

                    <x-inputs.group class="col-sm-12">
                        <x-inputs.textarea
                            name="puchaseitem.description"
                            label="Description"
                            wire:model="puchaseitem.description"
                            maxlength="255"
                        ></x-inputs.textarea>
                    </x-inputs.group>
                </div>
            </div>

            @if($editing) @endif

            <div class="modal-footer">
                <button
                    type="button"
                    class="btn btn-light float-left"
                    wire:click="$toggle('showingModal')"
                >
                    <i class="icon ion-md-close"></i>
                    @lang('crud.common.cancel')
                </button>

                <button type="button" class="btn btn-primary" wire:click="save">
                    <i class="icon ion-md-save"></i>
                    @lang('crud.common.save')
                </button>
            </div>
        </div>
    </x-modal>

    <div class="table-responsive">
        <table class="table table-borderless table-hover">
            <thead>
                <tr>
                    <th>
                        <input
                            type="checkbox"
                            wire:model="allSelected"
                            wire:click="toggleFullSelection"
                            title="{{ trans('crud.common.select_all') }}"
                        />
                    </th>
                    <th class="text-right">
                        @lang('crud.purchase_puchaseitems.inputs.qty')
                    </th>
                    <th class="text-right">
                        @lang('crud.purchase_puchaseitems.inputs.price')
                    </th>
                    <th class="text-left">
                        @lang('crud.purchase_puchaseitems.inputs.product_id')
                    </th>
                    <th class="text-left">
                        @lang('crud.purchase_puchaseitems.inputs.description')
                    </th>
                    <th></th>
                </tr>
            </thead>
            <tbody class="text-gray-600">
                @foreach ($purchaseitems as $purchaseitem)
                <tr class="hover:bg-gray-100">
                    <td class="text-left">
                        <input
                            type="checkbox"
                            value="{{ $purchaseitem->id }}"
                            wire:model="selected"
                        />
                    </td>
                    <td class="text-right">{{ $purchaseitem->qty ?? '-' }}</td>
                    <td class="text-right">
                        {{ $purchaseitem->price ?? '-' }}
                    </td>
                    <td class="text-left">
                        {{ optional($purchaseitem->product)->nm_product ?? '-'
                        }}
                    </td>
                    <td class="text-left">
                        {{ $purchaseitem->description ?? '-' }}
                    </td>
                    <td class="text-right" style="width: 134px;">
                        <div
                            role="group"
                            aria-label="Row Actions"
                            class="relative inline-flex align-middle"
                        >
                            @can('update', $purchaseitem)
                            <button
                                type="button"
                                class="btn btn-light"
                                wire:click="editPurchaseitem({{ $purchaseitem->id }})"
                            >
                                <i class="icon ion-md-create"></i>
                            </button>
                            @endcan
                        </div>
                    </td>
                </tr>
                @endforeach
            </tbody>
            <tfoot>
                <tr>
                    <td colspan="5">{{ $purchaseitems->render() }}</td>
                </tr>
            </tfoot>
        </table>
    </div>
</div>
