<?php

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\Api\SaleController;
use App\Http\Controllers\Api\AuthController;
use App\Http\Controllers\Api\CasheController;
use App\Http\Controllers\Api\AccountController;
use App\Http\Controllers\Api\ProductController;
use App\Http\Controllers\Api\PurchaseController;
use App\Http\Controllers\Api\SaleitemController;
use App\Http\Controllers\Api\SaleOrdersController;
use App\Http\Controllers\Api\ProductBuysController;
use App\Http\Controllers\Api\AccountSalesController;
use App\Http\Controllers\Api\CasheCaissesController;
use App\Http\Controllers\Api\ProductSellsController;
use App\Http\Controllers\Api\PurchaseitemController;
use App\Http\Controllers\Api\AccountCashesController;
use App\Http\Controllers\Api\AccountOrdersController;
use App\Http\Controllers\Api\SaleSaleitemsController;
use App\Http\Controllers\Api\AccountCaissesController;
use App\Http\Controllers\Api\PurchaseAchatsController;
use App\Http\Controllers\Api\SaleDeliveriesController;
use App\Http\Controllers\Api\AccountPurchasesController;
use App\Http\Controllers\Api\ProductSaleitemsController;
use App\Http\Controllers\Api\ProductPurchaseitemsController;
use App\Http\Controllers\Api\PurchasePurchaseitemsController;

/*
|--------------------------------------------------------------------------
| API Routes
|--------------------------------------------------------------------------
|
| Here is where you can register API routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| is assigned the "api" middleware group. Enjoy building your API!
|
*/

Route::post('/login', [AuthController::class, 'login'])->name('api.login');

Route::middleware('auth:sanctum')
    ->get('/user', function (Request $request) {
        return $request->user();
    })
    ->name('api.user');

Route::name('api.')
    ->middleware('auth:sanctum')
    ->group(function () {
        Route::apiResource('accounts', AccountController::class);

        // Account Purchases
        Route::get('/accounts/{account}/purchases', [
            AccountPurchasesController::class,
            'index',
        ])->name('accounts.purchases.index');
        Route::post('/accounts/{account}/purchases', [
            AccountPurchasesController::class,
            'store',
        ])->name('accounts.purchases.store');

        // Account Sales
        Route::get('/accounts/{account}/sales', [
            AccountSalesController::class,
            'index',
        ])->name('accounts.sales.index');
        Route::post('/accounts/{account}/sales', [
            AccountSalesController::class,
            'store',
        ])->name('accounts.sales.store');

        // Account Caches
        Route::get('/accounts/{account}/cashes', [
            AccountCashesController::class,
            'index',
        ])->name('accounts.cashes.index');
        Route::post('/accounts/{account}/cashes', [
            AccountCashesController::class,
            'store',
        ])->name('accounts.cashes.store');

        // Account Caisses
        Route::get('/accounts/{account}/caisses', [
            AccountCaissesController::class,
            'index',
        ])->name('accounts.caisses.index');
        Route::post('/accounts/{account}/caisses', [
            AccountCaissesController::class,
            'store',
        ])->name('accounts.caisses.store');

        // Account Orders
        Route::get('/accounts/{account}/orders', [
            AccountOrdersController::class,
            'index',
        ])->name('accounts.orders.index');
        Route::post('/accounts/{account}/orders', [
            AccountOrdersController::class,
            'store',
        ])->name('accounts.orders.store');

        // Route::apiResource('cashes', CasheController::class);
        Route::get('cashes/{cashe}', [CasheController::class, 'show',])->name('cashes.show');
        Route::put('cashes/{cashe}', [CasheController::class, 'update',])->name('cashes.update');
        Route::post('cashes', [CasheController::class, 'store',])->name('cashes.store');
        Route::delete('cashes/{cashe}', [CasheController::class, 'destroy',])->name('cashes.destroy');
        Route::get('cashes', [CasheController::class, 'index',])->name('cashes');

        Route::apiResource('products', ProductController::class);

        // Product Buys
        Route::get('/products/{product}/buys', [
            ProductBuysController::class,
            'index',
        ])->name('products.buys.index');
        Route::post('/products/{product}/buys', [
            ProductBuysController::class,
            'store',
        ])->name('products.buys.store');

        // Product Saleitems
        Route::get('/products/{product}/saleitems', [
            ProductSaleitemsController::class,
            'index',
        ])->name('products.saleitems.index');
        Route::post('/products/{product}/saleitems', [
            ProductSaleitemsController::class,
            'store',
        ])->name('products.saleitems.store');

        // Product Sells
        Route::get('/products/{product}/sells', [
            ProductSellsController::class,
            'index',
        ])->name('products.sells.index');
        Route::post('/products/{product}/sells', [
            ProductSellsController::class,
            'store',
        ])->name('products.sells.store');

        // Product Purchaseitems
        Route::get('/products/{product}/purchaseitems', [
            ProductPurchaseitemsController::class,
            'index',
        ])->name('products.purchaseitems.index');
        Route::post('/products/{product}/purchaseitems', [
            ProductPurchaseitemsController::class,
            'store',
        ])->name('products.purchaseitems.store');

        Route::apiResource('purchases', PurchaseController::class);

        // Purchase Achats
        Route::get('/purchases/{purchase}/achats', [
            PurchaseAchatsController::class,
            'index',
        ])->name('purchases.achats.index');
        Route::post('/purchases/{purchase}/achats', [
            PurchaseAchatsController::class,
            'store',
        ])->name('purchases.achats.store');

        // Purchase Purchaseitems
        Route::get('/purchases/{purchase}/purchaseitems', [
            PurchasePurchaseitemsController::class,
            'index',
        ])->name('purchases.purchaseitems.index');
        Route::post('/purchases/{purchase}/purchaseitems', [
            PurchasePurchaseitemsController::class,
            'store',
        ])->name('purchases.purchaseitems.store');

        Route::apiResource('sales', SaleController::class);

        // Sale Saleitems
        Route::get('/sales/{sale}/saleitems', [
            SaleSaleitemsController::class,
            'index',
        ])->name('sales.saleitems.index');
        Route::post('/sales/{sale}/saleitems', [
            SaleSaleitemsController::class,
            'store',
        ])->name('sales.saleitems.store');

        // Sale Deliveries
        Route::get('/sales/{sale}/deliveries', [
            SaleDeliveriesController::class,
            'index',
        ])->name('sales.deliveries.index');
        Route::post('/sales/{sale}/deliveries', [
            SaleDeliveriesController::class,
            'store',
        ])->name('sales.deliveries.store');

        // Sale Orders
        Route::get('/sales/{sale}/orders', [
            SaleOrdersController::class,
            'index',
        ])->name('sales.orders.index');
        Route::post('/sales/{sale}/orders', [
            SaleOrdersController::class,
            'store',
        ])->name('sales.orders.store');



        Route::get('/getaccounts', [
            AccountController::class,
            'getaccounts',
        ])->name('accounts.getaccounts');

        Route::get('/getaccountstatement/{account_id}', [
            AccountController::class,
            'getaccountstatement',
        ])->name('accounts.getaccountstatement');

        Route::get('/getstatement/{account_id}', [
            AccountController::class,
            'getstatement',
        ])->name('accounts.getstatement');

        Route::get('/getproducts', [
            ProductController::class,
            'getproducts',
        ])->name('products.getproducts');

        Route::get('/getstocks', [
            ProductController::class,
            'getstocks',
        ])->name('products.getstocks');

        Route::post('/getcashes', [
            CasheController::class,
            'getcashes',
        ])->name('cashes.getcashes');

        Route::get('/getcashecode', [
            CasheController::class,
            'getcashecode',
        ])->name('cashes.getcashecode');

        Route::post('/getsales', [
            SaleController::class,
            'getsales',
        ])->name('sales.getsales');

        Route::get('/getsalecode', [
            SaleController::class,
            'getsalecode',
        ])->name('sales.getsalecode');

        Route::post('/getpurchases', [
            PurchaseController::class,
            'getpurchases',
        ])->name('purchases.getpurchases');

        Route::get('/getpurchasecode', [
            PurchaseController::class,
            'getpurchasecode',
        ])->name('purchases.getpurchasecode');
    });
