<?php

namespace Tests\Feature\Api;

use App\Models\User;
use App\Models\Cashe;
use App\Models\Account;

use Tests\TestCase;
use Laravel\Sanctum\Sanctum;
use Illuminate\Foundation\Testing\WithFaker;
use Illuminate\Foundation\Testing\RefreshDatabase;

class AccountCashesTest extends TestCase
{
    use RefreshDatabase, WithFaker;

    protected function setUp(): void
    {
        parent::setUp();

        $user = User::factory()->create(['email' => 'admin@admin.com']);

        Sanctum::actingAs($user, [], 'web');

        $this->withoutExceptionHandling();
    }

    /**
     * @test
     */
    public function it_gets_account_cashes(): void
    {
        $account = Account::factory()->create();
        $cashes = Cashe::factory()
            ->count(2)
            ->create([
                'account_id' => $account->id,
            ]);

        $response = $this->getJson(
            route('api.accounts.cashes.index', $account)
        );

        $response->assertOk()->assertSee($cashes[0]->code);
    }

    /**
     * @test
     */
    public function it_stores_the_account_cashes(): void
    {
        $account = Account::factory()->create();
        $data = Cashe::factory()
            ->make([
                'account_id' => $account->id,
            ])
            ->toArray();

        $response = $this->postJson(
            route('api.accounts.cashes.store', $account),
            $data
        );

        $this->assertDatabaseHas('cashes', $data);

        $response->assertStatus(201)->assertJsonFragment($data);

        $cashe = Cashe::latest('id')->first();

        $this->assertEquals($account->id, $cashe->account_id);
    }
}
