<?php

namespace Tests\Feature\Api;

use App\Models\User;
use App\Models\Order;
use App\Models\Account;

use Tests\TestCase;
use Laravel\Sanctum\Sanctum;
use Illuminate\Foundation\Testing\WithFaker;
use Illuminate\Foundation\Testing\RefreshDatabase;

class AccountOrdersTest extends TestCase
{
    use RefreshDatabase, WithFaker;

    protected function setUp(): void
    {
        parent::setUp();

        $user = User::factory()->create(['email' => 'admin@admin.com']);

        Sanctum::actingAs($user, [], 'web');

        $this->withoutExceptionHandling();
    }

    /**
     * @test
     */
    public function it_gets_account_orders(): void
    {
        $account = Account::factory()->create();
        $orders = Order::factory()
            ->count(2)
            ->create([
                'account_id' => $account->id,
            ]);

        $response = $this->getJson(
            route('api.accounts.orders.index', $account)
        );

        $response->assertOk()->assertSee($orders[0]->code_order);
    }

    /**
     * @test
     */
    public function it_stores_the_account_orders(): void
    {
        $account = Account::factory()->create();
        $data = Order::factory()
            ->make([
                'account_id' => $account->id,
            ])
            ->toArray();

        $response = $this->postJson(
            route('api.accounts.orders.store', $account),
            $data
        );

        unset($data['account_id']);
        unset($data['code_order']);
        unset($data['dt_order']);
        unset($data['tot']);
        unset($data['rem_order']);
        unset($data['nb_colis']);
        unset($data['phase']);
        unset($data['status_order']);
        unset($data['user_order']);
        unset($data['preparation_par']);
        unset($data['enroute_par']);
        unset($data['conf_user']);
        unset($data['conf_par']);
        unset($data['dt_conf']);
        unset($data['id_tour']);
        unset($data['alger_id']);

        $this->assertDatabaseHas('orders', $data);

        $response->assertStatus(201)->assertJsonFragment($data);

        $order = Order::latest('id')->first();

        $this->assertEquals($account->id, $order->account_id);
    }
}
