<?php

namespace Tests\Feature\Api;

use App\Models\User;
use App\Models\Account;
use App\Models\Purchase;

use Tests\TestCase;
use Laravel\Sanctum\Sanctum;
use Illuminate\Foundation\Testing\WithFaker;
use Illuminate\Foundation\Testing\RefreshDatabase;

class AccountPurchasesTest extends TestCase
{
    use RefreshDatabase, WithFaker;

    protected function setUp(): void
    {
        parent::setUp();

        $user = User::factory()->create(['email' => 'admin@admin.com']);

        Sanctum::actingAs($user, [], 'web');

        $this->withoutExceptionHandling();
    }

    /**
     * @test
     */
    public function it_gets_account_purchases(): void
    {
        $account = Account::factory()->create();
        $purchases = Purchase::factory()
            ->count(2)
            ->create([
                'account_id' => $account->id,
            ]);

        $response = $this->getJson(
            route('api.accounts.purchases.index', $account)
        );

        $response->assertOk()->assertSee($purchases[0]->ref);
    }

    /**
     * @test
     */
    public function it_stores_the_account_purchases(): void
    {
        $account = Account::factory()->create();
        $data = Purchase::factory()
            ->make([
                'account_id' => $account->id,
            ])
            ->toArray();

        $response = $this->postJson(
            route('api.accounts.purchases.store', $account),
            $data
        );

        $this->assertDatabaseHas('purchases', $data);

        $response->assertStatus(201)->assertJsonFragment($data);

        $purchase = Purchase::latest('id')->first();

        $this->assertEquals($account->id, $purchase->account_id);
    }
}
