<?php

namespace Tests\Feature\Api;

use App\Models\User;
use App\Models\Sale;
use App\Models\Account;

use Tests\TestCase;
use Laravel\Sanctum\Sanctum;
use Illuminate\Foundation\Testing\WithFaker;
use Illuminate\Foundation\Testing\RefreshDatabase;

class AccountSalesTest extends TestCase
{
    use RefreshDatabase, WithFaker;

    protected function setUp(): void
    {
        parent::setUp();

        $user = User::factory()->create(['email' => 'admin@admin.com']);

        Sanctum::actingAs($user, [], 'web');

        $this->withoutExceptionHandling();
    }

    /**
     * @test
     */
    public function it_gets_account_sales(): void
    {
        $account = Account::factory()->create();
        $sales = Sale::factory()
            ->count(2)
            ->create([
                'account_id' => $account->id,
            ]);

        $response = $this->getJson(route('api.accounts.sales.index', $account));

        $response->assertOk()->assertSee($sales[0]->ref);
    }

    /**
     * @test
     */
    public function it_stores_the_account_sales(): void
    {
        $account = Account::factory()->create();
        $data = Sale::factory()
            ->make([
                'account_id' => $account->id,
            ])
            ->toArray();

        $response = $this->postJson(
            route('api.accounts.sales.store', $account),
            $data
        );

        $this->assertDatabaseHas('sales', $data);

        $response->assertStatus(201)->assertJsonFragment($data);

        $sale = Sale::latest('id')->first();

        $this->assertEquals($account->id, $sale->account_id);
    }
}
