<?php

namespace Tests\Feature\Api;

use App\Models\User;
use App\Models\Account;

use Tests\TestCase;
use Laravel\Sanctum\Sanctum;
use Illuminate\Foundation\Testing\WithFaker;
use Illuminate\Foundation\Testing\RefreshDatabase;

class AccountTest extends TestCase
{
    use RefreshDatabase, WithFaker;

    protected function setUp(): void
    {
        parent::setUp();

        $user = User::factory()->create(['email' => 'admin@admin.com']);

        Sanctum::actingAs($user, [], 'web');

        $this->withoutExceptionHandling();
    }

    /**
     * @test
     */
    public function it_gets_accounts_list(): void
    {
        $accounts = Account::factory()
            ->count(5)
            ->create();

        $response = $this->getJson(route('api.accounts.index'));

        $response->assertOk()->assertSee($accounts[0]->NOM);
    }

    /**
     * @test
     */
    public function it_stores_the_account(): void
    {
        $data = Account::factory()
            ->make()
            ->toArray();

        $response = $this->postJson(route('api.accounts.store'), $data);

        $this->assertDatabaseHas('accounts', $data);

        $response->assertStatus(201)->assertJsonFragment($data);
    }

    /**
     * @test
     */
    public function it_updates_the_account(): void
    {
        $account = Account::factory()->create();

        $user = User::factory()->create();

        $data = [
            'NOM' => $this->faker->name(),
            'cod' => $this->faker->text(255),
            'DATENT' => $this->faker->date(),
            'ADR' => $this->faker->text(255),
            'remise' => $this->faker->randomNumber(1),
            'max_c' => $this->faker->randomNumber(1),
            'sold' => $this->faker->randomNumber(1),
            'reg' => $this->faker->text(255),
            'fis' => $this->faker->text(255),
            'art' => $this->faker->text(255),
            'NIS' => $this->faker->text(255),
            'wilaya' => $this->faker->text(255),
            'email' => $this->faker->email(),
            'fix' => $this->faker->text(255),
            'fax' => $this->faker->text(255),
            'AGENT1' => $this->faker->text(255),
            'PHONE1' => $this->faker->text(255),
            'AGENT2' => $this->faker->text(255),
            'AGENT3' => $this->faker->text(255),
            'AGENT4' => $this->faker->text(255),
            'AGENT5' => $this->faker->text(255),
            'PHONE2' => $this->faker->text(255),
            'PHONE3' => $this->faker->text(255),
            'PHONE4' => $this->faker->text(255),
            'PHONE5' => $this->faker->text(255),
            'user_id' => $user->id,
        ];

        $response = $this->putJson(
            route('api.accounts.update', $account),
            $data
        );

        $data['id'] = $account->id;

        $this->assertDatabaseHas('accounts', $data);

        $response->assertOk()->assertJsonFragment($data);
    }

    /**
     * @test
     */
    public function it_deletes_the_account(): void
    {
        $account = Account::factory()->create();

        $response = $this->deleteJson(route('api.accounts.destroy', $account));

        $this->assertSoftDeleted($account);

        $response->assertNoContent();
    }
}
