<?php

namespace Tests\Feature\Api;

use App\Models\User;
use App\Models\Cashe;
use App\Models\Caisse;

use Tests\TestCase;
use Laravel\Sanctum\Sanctum;
use Illuminate\Foundation\Testing\WithFaker;
use Illuminate\Foundation\Testing\RefreshDatabase;

class CasheCaissesTest extends TestCase
{
    use RefreshDatabase, WithFaker;

    protected function setUp(): void
    {
        parent::setUp();

        $user = User::factory()->create(['email' => 'admin@admin.com']);

        Sanctum::actingAs($user, [], 'web');

        $this->withoutExceptionHandling();
    }

    /**
     * @test
     */
    public function it_gets_cashe_caisses(): void
    {
        $cashe = Cashe::factory()->create();
        $caisses = Caisse::factory()
            ->count(2)
            ->create([
                'alger_id' => $cashe->id,
            ]);

        $response = $this->getJson(route('api.cashes.caisses.index', $cashe));

        $response->assertOk()->assertSee($caisses[0]->code_caisse);
    }

    /**
     * @test
     */
    public function it_stores_the_cashe_caisses(): void
    {
        $cashe = Cashe::factory()->create();
        $data = Caisse::factory()
            ->make([
                'alger_id' => $cashe->id,
            ])
            ->toArray();

        $response = $this->postJson(
            route('api.cashes.caisses.store', $cashe),
            $data
        );

        unset($data['account_id']);
        unset($data['code_caisse']);
        unset($data['code_caisse_imp']);
        unset($data['designation']);
        unset($data['date_caisse']);
        unset($data['id_tour']);
        unset($data['alger_id']);

        $this->assertDatabaseHas('caisses', $data);

        $response->assertStatus(201)->assertJsonFragment($data);

        $caisse = Caisse::latest('id')->first();

        $this->assertEquals($cashe->id, $caisse->alger_id);
    }
}
