<?php

namespace Tests\Feature\Api;

use App\Models\User;
use App\Models\Cashe;

use App\Models\Tour;
use App\Models\Account;

use Tests\TestCase;
use Laravel\Sanctum\Sanctum;
use Illuminate\Foundation\Testing\WithFaker;
use Illuminate\Foundation\Testing\RefreshDatabase;

class CasheTest extends TestCase
{
    use RefreshDatabase, WithFaker;

    protected function setUp(): void
    {
        parent::setUp();

        $user = User::factory()->create(['email' => 'admin@admin.com']);

        Sanctum::actingAs($user, [], 'web');

        $this->withoutExceptionHandling();
    }

    /**
     * @test
     */
    public function it_gets_cashes_list(): void
    {
        $cashes = Cashe::factory()
            ->count(5)
            ->create();

        $response = $this->getJson(route('api.cashes.index'));

        $response->assertOk()->assertSee($cashes[0]->code);
    }

    /**
     * @test
     */
    public function it_stores_the_cashe(): void
    {
        $data = Cashe::factory()
            ->make()
            ->toArray();

        $response = $this->postJson(route('api.cashes.store'), $data);

        $this->assertDatabaseHas('cashes', $data);

        $response->assertStatus(201)->assertJsonFragment($data);
    }

    /**
     * @test
     */
    public function it_updates_the_cashe(): void
    {
        $cashe = Cashe::factory()->create();

        $account = Account::factory()->create();
        $tour = Tour::factory()->create();
        $user = User::factory()->create();

        $data = [
            'code' => $this->faker->text(255),
            'amount' => $this->faker->randomNumber(1),
            'date' => $this->faker->dateTime(),
            'in' => $this->faker->boolean(),
            'description' => $this->faker->sentence(15),
            'done' => $this->faker->boolean(),
            'account_id' => $account->id,
            'tour_id' => $tour->id,
            'user_id' => $user->id,
        ];

        $response = $this->putJson(route('api.cashes.update', $cashe), $data);

        $data['id'] = $cashe->id;

        $this->assertDatabaseHas('cashes', $data);

        $response->assertOk()->assertJsonFragment($data);
    }

    /**
     * @test
     */
    public function it_deletes_the_cashe(): void
    {
        $cashe = Cashe::factory()->create();

        $response = $this->deleteJson(route('api.cashes.destroy', $cashe));

        $this->assertSoftDeleted($cashe);

        $response->assertNoContent();
    }
}
