<?php

namespace Tests\Feature\Api;

use App\Models\Buy;
use App\Models\User;
use App\Models\Product;

use Tests\TestCase;
use Laravel\Sanctum\Sanctum;
use Illuminate\Foundation\Testing\WithFaker;
use Illuminate\Foundation\Testing\RefreshDatabase;

class ProductBuysTest extends TestCase
{
    use RefreshDatabase, WithFaker;

    protected function setUp(): void
    {
        parent::setUp();

        $user = User::factory()->create(['email' => 'admin@admin.com']);

        Sanctum::actingAs($user, [], 'web');

        $this->withoutExceptionHandling();
    }

    /**
     * @test
     */
    public function it_gets_product_buys(): void
    {
        $product = Product::factory()->create();
        $buys = Buy::factory()
            ->count(2)
            ->create([
                'product_id' => $product->id,
            ]);

        $response = $this->getJson(route('api.products.buys.index', $product));

        $response->assertOk()->assertSee($buys[0]->id);
    }

    /**
     * @test
     */
    public function it_stores_the_product_buys(): void
    {
        $product = Product::factory()->create();
        $data = Buy::factory()
            ->make([
                'product_id' => $product->id,
            ])
            ->toArray();

        $response = $this->postJson(
            route('api.products.buys.store', $product),
            $data
        );

        unset($data['qty']);
        unset($data['price']);
        unset($data['achat_id']);
        unset($data['product_id']);

        $this->assertDatabaseHas('buys', $data);

        $response->assertStatus(201)->assertJsonFragment($data);

        $buy = Buy::latest('id')->first();

        $this->assertEquals($product->id, $buy->product_id);
    }
}
