<?php

namespace Tests\Feature\Api;

use App\Models\User;
use App\Models\Product;
use App\Models\Saleitem;

use Tests\TestCase;
use Laravel\Sanctum\Sanctum;
use Illuminate\Foundation\Testing\WithFaker;
use Illuminate\Foundation\Testing\RefreshDatabase;

class ProductSaleitemsTest extends TestCase
{
    use RefreshDatabase, WithFaker;

    protected function setUp(): void
    {
        parent::setUp();

        $user = User::factory()->create(['email' => 'admin@admin.com']);

        Sanctum::actingAs($user, [], 'web');

        $this->withoutExceptionHandling();
    }

    /**
     * @test
     */
    public function it_gets_product_saleitems(): void
    {
        $product = Product::factory()->create();
        $saleitems = Saleitem::factory()
            ->count(2)
            ->create([
                'product_id' => $product->id,
            ]);

        $response = $this->getJson(
            route('api.products.saleitems.index', $product)
        );

        $response->assertOk()->assertSee($saleitems[0]->description);
    }

    /**
     * @test
     */
    public function it_stores_the_product_saleitems(): void
    {
        $product = Product::factory()->create();
        $data = Saleitem::factory()
            ->make([
                'product_id' => $product->id,
            ])
            ->toArray();

        $response = $this->postJson(
            route('api.products.saleitems.store', $product),
            $data
        );

        unset($data['sale_id']);

        $this->assertDatabaseHas('saleitems', $data);

        $response->assertStatus(201)->assertJsonFragment($data);

        $saleitem = Saleitem::latest('id')->first();

        $this->assertEquals($product->id, $saleitem->product_id);
    }
}
