<?php

namespace Tests\Feature\Api;

use App\Models\User;
use App\Models\Sell;
use App\Models\Product;

use Tests\TestCase;
use Laravel\Sanctum\Sanctum;
use Illuminate\Foundation\Testing\WithFaker;
use Illuminate\Foundation\Testing\RefreshDatabase;

class ProductSellsTest extends TestCase
{
    use RefreshDatabase, WithFaker;

    protected function setUp(): void
    {
        parent::setUp();

        $user = User::factory()->create(['email' => 'admin@admin.com']);

        Sanctum::actingAs($user, [], 'web');

        $this->withoutExceptionHandling();
    }

    /**
     * @test
     */
    public function it_gets_product_sells(): void
    {
        $product = Product::factory()->create();
        $sells = Sell::factory()
            ->count(2)
            ->create([
                'product_id' => $product->id,
            ]);

        $response = $this->getJson(route('api.products.sells.index', $product));

        $response->assertOk()->assertSee($sells[0]->id);
    }

    /**
     * @test
     */
    public function it_stores_the_product_sells(): void
    {
        $product = Product::factory()->create();
        $data = Sell::factory()
            ->make([
                'product_id' => $product->id,
            ])
            ->toArray();

        $response = $this->postJson(
            route('api.products.sells.store', $product),
            $data
        );

        unset($data['order_id']);
        unset($data['product_id']);
        unset($data['qte']);
        unset($data['price']);

        $this->assertDatabaseHas('sells', $data);

        $response->assertStatus(201)->assertJsonFragment($data);

        $sell = Sell::latest('id')->first();

        $this->assertEquals($product->id, $sell->product_id);
    }
}
