<?php

namespace Tests\Feature\Api;

use App\Models\User;
use App\Models\Achat;
use App\Models\Purchase;

use Tests\TestCase;
use Laravel\Sanctum\Sanctum;
use Illuminate\Foundation\Testing\WithFaker;
use Illuminate\Foundation\Testing\RefreshDatabase;

class PurchaseAchatsTest extends TestCase
{
    use RefreshDatabase, WithFaker;

    protected function setUp(): void
    {
        parent::setUp();

        $user = User::factory()->create(['email' => 'admin@admin.com']);

        Sanctum::actingAs($user, [], 'web');

        $this->withoutExceptionHandling();
    }

    /**
     * @test
     */
    public function it_gets_purchase_achats(): void
    {
        $purchase = Purchase::factory()->create();
        $achats = Achat::factory()
            ->count(2)
            ->create([
                'alger_id' => $purchase->id,
            ]);

        $response = $this->getJson(
            route('api.purchases.achats.index', $purchase)
        );

        $response->assertOk()->assertSee($achats[0]->code_achat);
    }

    /**
     * @test
     */
    public function it_stores_the_purchase_achats(): void
    {
        $purchase = Purchase::factory()->create();
        $data = Achat::factory()
            ->make([
                'alger_id' => $purchase->id,
            ])
            ->toArray();

        $response = $this->postJson(
            route('api.purchases.achats.store', $purchase),
            $data
        );

        unset($data['code_achat']);
        unset($data['code_imp']);
        unset($data['dt_achat']);
        unset($data['tot']);
        unset($data['rem_achat']);
        unset($data['nb_colis']);
        unset($data['phases']);
        unset($data['status_achat']);
        unset($data['user_achat']);
        unset($data['preparation_par']);
        unset($data['enroute_par']);
        unset($data['conf_user']);
        unset($data['conf_par']);
        unset($data['dt_conf']);
        unset($data['id_tour']);
        unset($data['alger_id']);

        $this->assertDatabaseHas('achats', $data);

        $response->assertStatus(201)->assertJsonFragment($data);

        $achat = Achat::latest('id')->first();

        $this->assertEquals($purchase->id, $achat->alger_id);
    }
}
