<?php

namespace Tests\Feature\Api;

use App\Models\User;
use App\Models\Purchase;
use App\Models\Purchaseitem;

use Tests\TestCase;
use Laravel\Sanctum\Sanctum;
use Illuminate\Foundation\Testing\WithFaker;
use Illuminate\Foundation\Testing\RefreshDatabase;

class PurchasePurchaseitemsTest extends TestCase
{
    use RefreshDatabase, WithFaker;

    protected function setUp(): void
    {
        parent::setUp();

        $user = User::factory()->create(['email' => 'admin@admin.com']);

        Sanctum::actingAs($user, [], 'web');

        $this->withoutExceptionHandling();
    }

    /**
     * @test
     */
    public function it_gets_purchase_purchaseitems(): void
    {
        $purchase = Purchase::factory()->create();
        $purchaseitems = Purchaseitem::factory()
            ->count(2)
            ->create([
                'purchase_id' => $purchase->id,
            ]);

        $response = $this->getJson(
            route('api.purchases.purchaseitems.index', $purchase)
        );

        $response->assertOk()->assertSee($purchaseitems[0]->description);
    }

    /**
     * @test
     */
    public function it_stores_the_purchase_purchaseitems(): void
    {
        $purchase = Purchase::factory()->create();
        $data = Purchaseitem::factory()
            ->make([
                'purchase_id' => $purchase->id,
            ])
            ->toArray();

        $response = $this->postJson(
            route('api.purchases.purchaseitems.store', $purchase),
            $data
        );

        unset($data['purchase_id']);

        $this->assertDatabaseHas('purchaseitems', $data);

        $response->assertStatus(201)->assertJsonFragment($data);

        $purchaseitem = Purchaseitem::latest('id')->first();

        $this->assertEquals($purchase->id, $purchaseitem->purchase_id);
    }
}
