<?php

namespace Tests\Feature\Api;

use App\Models\User;
use App\Models\Purchase;

use App\Models\Account;

use Tests\TestCase;
use Laravel\Sanctum\Sanctum;
use Illuminate\Foundation\Testing\WithFaker;
use Illuminate\Foundation\Testing\RefreshDatabase;

class PurchaseTest extends TestCase
{
    use RefreshDatabase, WithFaker;

    protected function setUp(): void
    {
        parent::setUp();

        $user = User::factory()->create(['email' => 'admin@admin.com']);

        Sanctum::actingAs($user, [], 'web');

        $this->withoutExceptionHandling();
    }

    /**
     * @test
     */
    public function it_gets_purchases_list(): void
    {
        $purchases = Purchase::factory()
            ->count(5)
            ->create();

        $response = $this->getJson(route('api.purchases.index'));

        $response->assertOk()->assertSee($purchases[0]->ref);
    }

    /**
     * @test
     */
    public function it_stores_the_purchase(): void
    {
        $data = Purchase::factory()
            ->make()
            ->toArray();

        $response = $this->postJson(route('api.purchases.store'), $data);

        $this->assertDatabaseHas('purchases', $data);

        $response->assertStatus(201)->assertJsonFragment($data);
    }

    /**
     * @test
     */
    public function it_updates_the_purchase(): void
    {
        $purchase = Purchase::factory()->create();

        $account = Account::factory()->create();
        $user = User::factory()->create();

        $data = [
            'ref' => $this->faker->text(255),
            'code' => $this->faker->text(255),
            'date' => $this->faker->dateTime(),
            'remise' => $this->faker->randomNumber(1),
            'description' => $this->faker->sentence(15),
            'done' => $this->faker->boolean(),
            'account_id' => $account->id,
            'user_id' => $user->id,
        ];

        $response = $this->putJson(
            route('api.purchases.update', $purchase),
            $data
        );

        $data['id'] = $purchase->id;

        $this->assertDatabaseHas('purchases', $data);

        $response->assertOk()->assertJsonFragment($data);
    }

    /**
     * @test
     */
    public function it_deletes_the_purchase(): void
    {
        $purchase = Purchase::factory()->create();

        $response = $this->deleteJson(
            route('api.purchases.destroy', $purchase)
        );

        $this->assertSoftDeleted($purchase);

        $response->assertNoContent();
    }
}
