<?php

namespace Tests\Feature\Api;

use App\Models\User;
use App\Models\Sale;
use App\Models\Delivery;

use Tests\TestCase;
use Laravel\Sanctum\Sanctum;
use Illuminate\Foundation\Testing\WithFaker;
use Illuminate\Foundation\Testing\RefreshDatabase;

class SaleDeliveriesTest extends TestCase
{
    use RefreshDatabase, WithFaker;

    protected function setUp(): void
    {
        parent::setUp();

        $user = User::factory()->create(['email' => 'admin@admin.com']);

        Sanctum::actingAs($user, [], 'web');

        $this->withoutExceptionHandling();
    }

    /**
     * @test
     */
    public function it_gets_sale_deliveries(): void
    {
        $sale = Sale::factory()->create();
        $deliveries = Delivery::factory()
            ->count(2)
            ->create([
                'sale_id' => $sale->id,
            ]);

        $response = $this->getJson(route('api.sales.deliveries.index', $sale));

        $response->assertOk()->assertSee($deliveries[0]->conf_ent);
    }

    /**
     * @test
     */
    public function it_stores_the_sale_deliveries(): void
    {
        $sale = Sale::factory()->create();
        $data = Delivery::factory()
            ->make([
                'sale_id' => $sale->id,
            ])
            ->toArray();

        $response = $this->postJson(
            route('api.sales.deliveries.store', $sale),
            $data
        );

        unset($data['sale_id']);
        unset($data['price']);
        unset($data['from']);
        unset($data['to']);
        unset($data['date_ent']);
        unset($data['date_sort']);
        unset($data['conf_ent']);
        unset($data['conf_sort']);
        unset($data['user_ent']);
        unset($data['user_sort']);
        unset($data['description']);

        $this->assertDatabaseHas('deliveries', $data);

        $response->assertStatus(201)->assertJsonFragment($data);

        $delivery = Delivery::latest('id')->first();

        $this->assertEquals($sale->id, $delivery->sale_id);
    }
}
