<?php

namespace Tests\Feature\Api;

use App\Models\User;
use App\Models\Sale;
use App\Models\Saleitem;

use Tests\TestCase;
use Laravel\Sanctum\Sanctum;
use Illuminate\Foundation\Testing\WithFaker;
use Illuminate\Foundation\Testing\RefreshDatabase;

class SaleSaleitemsTest extends TestCase
{
    use RefreshDatabase, WithFaker;

    protected function setUp(): void
    {
        parent::setUp();

        $user = User::factory()->create(['email' => 'admin@admin.com']);

        Sanctum::actingAs($user, [], 'web');

        $this->withoutExceptionHandling();
    }

    /**
     * @test
     */
    public function it_gets_sale_saleitems(): void
    {
        $sale = Sale::factory()->create();
        $saleitems = Saleitem::factory()
            ->count(2)
            ->create([
                'sale_id' => $sale->id,
            ]);

        $response = $this->getJson(route('api.sales.saleitems.index', $sale));

        $response->assertOk()->assertSee($saleitems[0]->description);
    }

    /**
     * @test
     */
    public function it_stores_the_sale_saleitems(): void
    {
        $sale = Sale::factory()->create();
        $data = Saleitem::factory()
            ->make([
                'sale_id' => $sale->id,
            ])
            ->toArray();

        $response = $this->postJson(
            route('api.sales.saleitems.store', $sale),
            $data
        );

        unset($data['sale_id']);

        $this->assertDatabaseHas('saleitems', $data);

        $response->assertStatus(201)->assertJsonFragment($data);

        $saleitem = Saleitem::latest('id')->first();

        $this->assertEquals($sale->id, $saleitem->sale_id);
    }
}
