<?php

namespace Tests\Feature\Api;

use App\Models\User;
use App\Models\Sale;

use App\Models\Account;

use Tests\TestCase;
use Laravel\Sanctum\Sanctum;
use Illuminate\Foundation\Testing\WithFaker;
use Illuminate\Foundation\Testing\RefreshDatabase;

class SaleTest extends TestCase
{
    use RefreshDatabase, WithFaker;

    protected function setUp(): void
    {
        parent::setUp();

        $user = User::factory()->create(['email' => 'admin@admin.com']);

        Sanctum::actingAs($user, [], 'web');

        $this->withoutExceptionHandling();
    }

    /**
     * @test
     */
    public function it_gets_sales_list(): void
    {
        $sales = Sale::factory()
            ->count(5)
            ->create();

        $response = $this->getJson(route('api.sales.index'));

        $response->assertOk()->assertSee($sales[0]->ref);
    }

    /**
     * @test
     */
    public function it_stores_the_sale(): void
    {
        $data = Sale::factory()
            ->make()
            ->toArray();

        $response = $this->postJson(route('api.sales.store'), $data);

        $this->assertDatabaseHas('sales', $data);

        $response->assertStatus(201)->assertJsonFragment($data);
    }

    /**
     * @test
     */
    public function it_updates_the_sale(): void
    {
        $sale = Sale::factory()->create();

        $account = Account::factory()->create();
        $user = User::factory()->create();

        $data = [
            'ref' => $this->faker->text(255),
            'code' => $this->faker->text(255),
            'date' => $this->faker->dateTime(),
            'remise' => $this->faker->randomNumber(1),
            'description' => $this->faker->sentence(15),
            'done' => $this->faker->boolean(),
            'account_id' => $account->id,
            'user_id' => $user->id,
        ];

        $response = $this->putJson(route('api.sales.update', $sale), $data);

        $data['id'] = $sale->id;

        $this->assertDatabaseHas('sales', $data);

        $response->assertOk()->assertJsonFragment($data);
    }

    /**
     * @test
     */
    public function it_deletes_the_sale(): void
    {
        $sale = Sale::factory()->create();

        $response = $this->deleteJson(route('api.sales.destroy', $sale));

        $this->assertDeleted($sale);

        $response->assertNoContent();
    }
}
