<?php

// Read the configuration file
$config = parse_ini_file('./config.ini', true);

// Access the configuration values
$sourceHost = $config['source']['host'] ?? '';
$sourceUsername = $config['source']['username'] ?? '';
$sourcePassword = $config['source']['password'] ?? '';
$sourceDatabase = $config['source']['database'] ?? '';
$sourcePort = $config['source']['port'] ?? '';

$destHost = $config['dest']['host'] ?? '';
$destUsername = $config['dest']['username'] ?? '';
$destPassword = $config['dest']['password'] ?? '';
$destDatabase = $config['dest']['database'] ?? '';
$destPort = $config['dest']['port'] ?? '';

try {
    // Establish connection to the destination database
    $destConn = new mysqli($destHost, $destUsername, $destPassword, $destDatabase, $destPort);
    $destConn->set_charset("utf8mb4");
    if ($destConn->connect_error) {
        throw new Exception("Connection to destination database failed: " . $destConn->connect_error);
    }

    // Establish connection to the source database
    $sourceConn = new mysqli($sourceHost, $sourceUsername, $sourcePassword, $sourceDatabase, $sourcePort);
    $sourceConn->set_charset("utf8mb4");
    if ($sourceConn->connect_error) {
        throw new Exception("Connection to source database failed: " . $sourceConn->connect_error);
    }

    // Disable foreign key checks
    $destConn->query("SET foreign_key_checks = 0");

    // Check if the destination table exists before truncating
    $result = $destConn->query("SHOW TABLES LIKE 'achats'");
    if ($result && $result->num_rows > 0) {
        $destConn->query("TRUNCATE TABLE achats");
    }

    // Select data from the source table
    $sourceTableName = 'achats';
    $retrieveResult = $sourceConn->query("SELECT * FROM $sourceTableName");

    if ($retrieveResult && $retrieveResult->num_rows > 0) {
        // Use prepared statements for inserting data
        $insertQuery = "INSERT INTO achats (id, code_achat, code_imp, account_id, dt_achat, tot, rem_achat, nb_colis, phases, status_achat, user_achat, preparation_par, enroute_par, conf_user, conf_par, dt_conf, id_tour, alger_id) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)";

        $stmt = $destConn->prepare($insertQuery);
        if (!$stmt) {
            throw new Exception("Prepare failed: " . $destConn->error);
        }

        while ($row = $retrieveResult->fetch_assoc()) {
            $stmt->bind_param(
                "isssssssssssssssss",
                $row['id_achat'],
                $row['code_achat'],
                $row['code_imp'],
                $row['id_client'],
                $row['dt_achat'],
                $row['tot'],
                $row['rem_achat'],
                $row['nb_colis'],
                $row['phases'],
                $row['status_achat'],
                $row['user_achat'],
                $row['preparation_par'],
                $row['enroute_par'],
                $row['conf_user'],
                $row['conf_par'],
                $row['dt_conf'],
                $row['id_tour'],
                $row['alger_id']
            );

            if (!$stmt->execute()) {
                echo "Error inserting data into destination table: Achats " . $stmt->error . "<br>";
            }
        }

        $stmt->close();
        echo "Achats sync completed successfully.<br>";
    } else {
        echo "No Achats found.<br>";
    }
} catch (Exception $e) {
    echo "An error occurred: " . $e->getMessage();
} finally {
    // Ensure both connections are closed
    if (isset($sourceConn) && $sourceConn->ping()) {
        $sourceConn->close();
    }
    if (isset($destConn) && $destConn->ping()) {
        $destConn->close();
    }
}
