<?php

// Read the configuration file
$config = parse_ini_file('./config.ini', true);

// Access the configuration values
$sourceHost = $config['source']['host'];
$sourceUsername = $config['source']['username'];
$sourcePassword = $config['source']['password'];
$sourceDatabase = $config['source']['database'];
$sourcePort = $config['source']['port'];

$destHost = $config['dest']['host'];
$destUsername = $config['dest']['username'];
$destPassword = $config['dest']['password'];
$destDatabase = $config['dest']['database'];
$destPort = $config['dest']['port'];

try {
    // Establish connection to the destination database
    $destConn = new mysqli($destHost, $destUsername, $destPassword, $destDatabase, $destPort);
    $destConn->set_charset("utf8mb4");
    if ($destConn->connect_error) {
        throw new Exception("Connection to destination database failed: " . $destConn->connect_error);
    }

    // Establish connection to the source database
    $sourceConn = new mysqli($sourceHost, $sourceUsername, $sourcePassword, $sourceDatabase, $sourcePort);
    $sourceConn->set_charset("utf8mb4");
    if ($sourceConn->connect_error) {
        throw new Exception("Connection to source database failed: " . $sourceConn->connect_error);
    }

    // Disable foreign key checks
    $foreignKeyChecks = "SET foreign_key_checks = 0";
    $destConn->query($foreignKeyChecks);

    // Check if the destination table exists before truncating
    if ($destConn->query("SHOW TABLES LIKE 'buys'")->num_rows > 0) {
        $truncateQuery = "TRUNCATE TABLE buys"; // Use "DELETE FROM buys" if you want to delete instead of truncate
        $destConn->query($truncateQuery);
    }

    // Retrieve data from the source table
    $retrieveQuery = "SELECT * FROM buys";
    $retrieveResult = $sourceConn->query($retrieveQuery);

    if ($retrieveResult && $retrieveResult->num_rows > 0) {
        // Prepare the insert statement
        $insertQuery = "INSERT INTO buys (id, achat_id, product_id, qte, price) VALUES (?, ?, ?, ?, ?)";

        $stmt = $destConn->prepare($insertQuery);
        if (!$stmt) {
            throw new Exception("Prepare failed: " . $destConn->error);
        }

        while ($row = $retrieveResult->fetch_assoc()) {
            $stmt->bind_param(
                "iisds",
                $row['id_buy'],
                $row['id_achat'],
                $row['id_product'],
                $row['qte'],
                $row['price']
            );

            if (!$stmt->execute()) {
                echo "Error inserting data into destination table: buys " . $stmt->error . "<br>";
            }
        }

        $stmt->close();
        echo "Buys sync completed successfully.<br>";
    } else {
        echo "No Buys found.<br>";
    }
} catch (Exception $e) {
    echo "An error occurred: " . $e->getMessage();
} finally {
    // Ensure both connections are closed
    if (isset($sourceConn)) {
        $sourceConn->close();
    }
    if (isset($destConn)) {
        $destConn->close();
    }
}
