<?php

// Read the configuration file
$config = parse_ini_file('./config.ini', true);

// Access the configuration values
$sourceHost = $config['source']['host'];
$sourceUsername = $config['source']['username'];
$sourcePassword = $config['source']['password'];
$sourceDatabase = $config['source']['database'];
$sourcePort = $config['source']['port'];

$destHost = $config['dest']['host'];
$destUsername = $config['dest']['username'];
$destPassword = $config['dest']['password'];
$destDatabase = $config['dest']['database'];
$destPort = $config['dest']['port'];

try {
    // Establish connection to the destination database
    $destConn = new mysqli($destHost, $destUsername, $destPassword, $destDatabase, $destPort);
    $destConn->set_charset("utf8mb4");
    if ($destConn->connect_error) {
        throw new Exception("Connection to destination database failed: " . $destConn->connect_error);
    }

    // Establish connection to the source database
    $sourceConn = new mysqli($sourceHost, $sourceUsername, $sourcePassword, $sourceDatabase, $sourcePort);
    $sourceConn->set_charset("utf8mb4");
    if ($sourceConn->connect_error) {
        throw new Exception("Connection to source database failed: " . $sourceConn->connect_error);
    }

    // Disable foreign key checks
    $foreignKeyChecks = "SET foreign_key_checks = 0";
    $destConn->query($foreignKeyChecks);

    // Check if the destination table exists before truncating
    if ($destConn->query("SHOW TABLES LIKE 'accounts'")->num_rows > 0) {
        $truncateQuery = "TRUNCATE TABLE accounts";
        $destConn->query($truncateQuery);
    }

    // Retrieve data from the source table
    $retrieveQuery = "SELECT * FROM client";
    $retrieveResult = $sourceConn->query($retrieveQuery);

    if ($retrieveResult && $retrieveResult->num_rows > 0) {
        // Use prepared statements for inserting data
        $insertQuery = "INSERT INTO accounts (
       id, cod, DATENT, NOM, ADR, remise, max_c, sold, reg, fis, art, NIS, wilaya, email, fix, fax, AGENT1, PHONE1, AGENT2, PHONE2, AGENT3, PHONE3, AGENT4, PHONE4, AGENT5, PHONE5) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)";

        $stmt = $destConn->prepare($insertQuery);
        if (!$stmt) {
            throw new Exception("Prepare failed: " . $destConn->error);
        }

        while ($row = $retrieveResult->fetch_assoc()) {
            $stmt->bind_param(
                "isssssssssssssssssssssssss",
                $row['id'],
                $row['cod'],
                $row['DATENT'],
                $row['NOM'],
                $row['ADR'],
                $row['remise'],
                $row['max_c'],
                $row['sold'],
                $row['reg'],
                $row['fis'],
                $row['art'],
                $row['NIS'],
                $row['WILAYA'],
                $row['EMAIL'],
                $row['fix'],
                $row['fax'],
                $row['AGENT1'],
                $row['PHONE1'],
                $row['AGENT2'],
                $row['PHONE2'],
                $row['AGENT3'],
                $row['PHONE3'],
                $row['AGENT4'],
                $row['PHONE4'],
                $row['AGENT5'],
                $row['PHONE5']
            );

            if (!$stmt->execute()) {
                echo "Error inserting data into destination table: " . $stmt->error . "<br>";
            }
        }

        $stmt->close();
        echo "Clients sync completed successfully.<br>";
    } else {
        echo "No Clients found.<br>";
    }
} catch (Exception $e) {
    echo "An error occurred: " . $e->getMessage();
} finally {
    // Ensure both connections are closed
    if (isset($sourceConn)) {
        $sourceConn->close();
    }
    if (isset($destConn)) {
        $destConn->close();
    }
}
