<?php

// Read the configuration file
$config = parse_ini_file('./config.ini', true);

// Access the configuration values for the source and destination databases
$sourceHost = $config['source']['host'];
$sourceUsername = $config['source']['username'];
$sourcePassword = $config['source']['password'];
$sourceDatabase = $config['source']['database'];
$sourcePort = $config['source']['port'];

$destHost = $config['dest']['host'];
$destUsername = $config['dest']['username'];
$destPassword = $config['dest']['password'];
$destDatabase = $config['dest']['database'];
$destPort = $config['dest']['port'];

try {
    // Establish connection to the destination database
    $destConn = new mysqli($destHost, $destUsername, $destPassword, $destDatabase, $destPort);
    $destConn->set_charset("utf8mb4");
    if ($destConn->connect_error) {
        throw new Exception("Connection to destination database failed: " . $destConn->connect_error);
    }

    // Establish connection to the source database
    $sourceConn = new mysqli($sourceHost, $sourceUsername, $sourcePassword, $sourceDatabase, $sourcePort);
    $sourceConn->set_charset("utf8mb4");
    if ($sourceConn->connect_error) {
        throw new Exception("Connection to source database failed: " . $sourceConn->connect_error);
    }

    // Disable foreign key checks in the destination database
    $destConn->query("SET foreign_key_checks = 0");

    // Truncate the destination table if it exists
    if ($destConn->query("SHOW TABLES LIKE 'products'")->num_rows > 0) {
        $truncateQuery = "TRUNCATE TABLE products";
        $destConn->query($truncateQuery);
    }

    // Retrieve data from the source table
    $retrieveQuery = "SELECT * FROM products";
    $retrieveResult = $sourceConn->query($retrieveQuery);

    if ($retrieveResult && $retrieveResult->num_rows > 0) {
        // Prepare the insert statement
        $insertQuery = "INSERT INTO products (id, nm_product, n°, barecode, code_product, qtu_product, qc, qu, fr_nm_product, serie_id, price_product, img_product)
                        VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)";

        $stmt = $destConn->prepare($insertQuery);
        if (!$stmt) {
            throw new Exception("Prepare failed: " . $destConn->error);
        }

        // Bind and execute the prepared statement for each row
        while ($row = $retrieveResult->fetch_assoc()) {
            $stmt->bind_param(
                "isssssssssis",
                $row['id_product'],
                $row['nm_product'],
                $row['n°'],
                $row['barecode'],
                $row['code_product'],
                $row['qtu_product'],
                $row['qc'],
                $row['qu'],
                $row['fr_nm_product'],
                $row['id_serie'],
                $row['price_product'],
                $row['img_product']
            );

            if (!$stmt->execute()) {
                echo "Error inserting data into destination table: " . $stmt->error . "<br>";
            }
        }

        $stmt->close();
        echo "Products sync completed successfully.<br>";
    } else {
        echo "No products found.<br>";
    }
} catch (Exception $e) {
    echo "An error occurred: " . $e->getMessage();
} finally {
    // Ensure both connections are closed
    if (isset($sourceConn)) {
        $sourceConn->close();
    }
    if (isset($destConn)) {
        $destConn->close();
    }
}
